/*
 * Copyright (c) 2008 Jiri Svoboda
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup debug
 * @{
 */
/** @file
 */

#ifndef DTHREAD_H_
#define DTHREAD_H_

#include <udebug.h>
#include <fibril.h>
#include <libadt/list.h>

#include "include/arch/types.h"

typedef struct {
	int id;		/* human-friendly id */
	thash_t hash;	/* system hash */
	fid_t fid;	/* id of servicing fibril */
	int stopped;

	/** Link to list of debugged threads */
	link_t link;

	dthread_arch_t arch;
} dthread_t;

extern link_t dthreads;		/* List of application's threads */
extern dthread_t *cwt;

dthread_t *dthread_new(thash_t hash);
void dthread_delete(dthread_t *dthread);
dthread_t *dthread_get_by_fid(fid_t fid);
dthread_t *dthread_get(void);
void dthread_stop_me(void);
void dthread_resume(dthread_t *dt);

unsigned dthread_get_pc(dthread_t *dthread);

#endif

/** @}
 */
